@@ -1,4 +1,4 @@
-/* $Header: /home/cvsroot/NetZ3950/yazwrap/ywpriv.h,v 1.3 2003/01/21 16:46:41 mike Exp $ */
+/* $Header: /home/cvsroot/NetZ3950/yazwrap/ywpriv.h,v 1.5 2005/05/25 14:27:28 mike Exp $ */
 
 #include "EXTERN.h"		/* Prerequisite for "perl.h" */
 #define yaz_log __some_stupid_function_in_the_linux_math_library
@@ -6,6 +6,8 @@
 #include "XSUB.h"
 #undef yaz_log
 #undef simple
+#undef list
+#undef open
 /*
  * Explanations for the above bits of brain damage.
  *
@@ -20,7 +22,9 @@
  * I find it truly hard to believe this, but "embed.h" (included by
  * "perl.h") #defines the token "simple" to "Perl_simple", which means
  * we can't access the `simple' element of Yaz's Z_RecordComposition
- * structure.  So this has to be explicitly undefined.  Bleaurrgh.
+ * structure.  So this has to be explicitly undefined.  Same for
+ * "list", which dets defined to "Perl_list".  Bleaurrgh.  And "open"
+ * gets defined to "open64" on some platforms, e.g. Solaris 9.
  */
 
 #include "yazwrap.h"
